@@ -1,4 +1,5 @@
 // Copyright (C) 2010-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU uCommon C++.
 //
@@ -129,7 +130,7 @@ static void zerofill(const char *devname)
             _TEXT("failed before end of space"));
 }
 
-PROGRAM_MAIN(argc, argv)
+int main(int argc, char **argv)
 {
     shell::bind("zerofill");
     shell args(argc, argv);
@@ -145,7 +146,7 @@ PROGRAM_MAIN(argc, argv)
         printf("%s\n", _TEXT("Options:"));
         shell::help();
         printf("\n%s\n", _TEXT("Report bugs to dyfet@gnu.org"));
-        PROGRAM_EXIT(0);
+        return 0;
     }
 
     secure::init();
@@ -158,6 +159,6 @@ PROGRAM_MAIN(argc, argv)
     while(count < args() && live)
         zerofill(args[count++]);
 
-    PROGRAM_EXIT(0);
+    return 0;
 }
 
